@@ -23,7 +23,7 @@
 
 namespace Mercator {
 
-inline unsigned int BasePoint::seed() const
+unsigned int BasePoint::seed() const
 {
     return I_ROUND(m_height * 1000.0);
 }
