@@ -29,8 +29,8 @@ Segment::~Segment()
 {
 }
 
-const float BasePoint::HEIGHT;
-const float BasePoint::ROUGHNESS;
-const float BasePoint::FALLOFF;
+const float BasePoint::HEIGHT = 8.0;
+const float BasePoint::ROUGHNESS = 1.25;
+const float BasePoint::FALLOFF = 0.25;
 
 }
