@@ -39,9 +39,9 @@ int main()
 
 namespace Mercator {
 
-const float BasePoint::HEIGHT;
-const float BasePoint::ROUGHNESS;
-const float BasePoint::FALLOFF;
+const float BasePoint::HEIGHT = 8.0;
+const float BasePoint::ROUGHNESS = 1.25;
+const float BasePoint::FALLOFF = 0.25;
 
 void Surface::populate()
 {
